require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_registrypolicyfile',
  dscmeta_resource_friendly_name: 'RegistryPolicyFile',
  dscmeta_resource_name: 'MSFT_RegistryPolicyFile',
  dscmeta_module_name: 'GPRegistryPolicyDsc',
  dscmeta_module_version: '1.0.0',
  docs: 'The DSC RegistryPolicyFile resource type.
         Automatically generated from version 1.0.0',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_valuename: {
      type: 'String',
      desc: 'Indicates the name of the registry value.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_accountname: {
      type: 'Optional[String]',
      desc: 'Specifies the name of the account for an user specific pol file to be managed.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_key: {
      type: 'String',
      desc: 'Indicates the path of the registry key for which you want to ensure a specific state.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: "Specifies the desired state of the registry policy. When set to 'Present', the registry policy will be created. When set to 'Absent', the registry policy will be removed. Default value is 'Present'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_valuetype: {
      type: "Optional[Enum['Binary', 'Dword', 'ExpandString', 'MultiString', 'Qword', 'String', 'None']]",
      desc: 'Indicates the type of the value.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_targettype: {
      type: "Enum['ComputerConfiguration', 'UserConfiguration', 'Administrators', 'NonAdministrators', 'Account']",
      desc: 'Indicates the target type. This is needed to determine the .pol file path. Supported values are ComputerConfiguration, UserConfiguration, Administrators, NonAdministrators, and Account.',

      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'Optional[String]',
      desc: 'Returns the path to the pol file being managed.',
      behaviour: :read_only,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_valuedata: {
      type: 'Optional[Array[String]]',
      desc: 'The data for the registry value.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String[]',
      mof_is_embedded: false,
    },
  },
)
